@@ -17,7 +17,7 @@
 package command
 
 import (
-	gocontext "context"
+	"context"
 	"fmt"
 	"io"
 	"net"
@@ -27,16 +27,16 @@ import (
 	"runtime"
 	"time"
 
-	"github.com/containerd/containerd/defaults"
-	"github.com/containerd/containerd/errdefs"
-	"github.com/containerd/containerd/log"
-	_ "github.com/containerd/containerd/metrics" // import containerd build info
-	"github.com/containerd/containerd/mount"
-	"github.com/containerd/containerd/services/server"
-	srvconfig "github.com/containerd/containerd/services/server/config"
-	"github.com/containerd/containerd/sys"
-	"github.com/containerd/containerd/version"
-	"github.com/urfave/cli"
+	"github.com/containerd/containerd/v2/cmd/containerd/server"
+	srvconfig "github.com/containerd/containerd/v2/cmd/containerd/server/config"
+	_ "github.com/containerd/containerd/v2/core/metrics" // import containerd build info
+	"github.com/containerd/containerd/v2/core/mount"
+	"github.com/containerd/containerd/v2/defaults"
+	"github.com/containerd/containerd/v2/pkg/sys"
+	"github.com/containerd/containerd/v2/version"
+	"github.com/containerd/errdefs"
+	"github.com/containerd/log"
+	"github.com/urfave/cli/v2"
 	"google.golang.org/grpc/grpclog"
 )
 
@@ -54,8 +54,18 @@ func init() {
 	// Discard grpc logs so that they don't mess with our stdio
 	grpclog.SetLoggerV2(grpclog.NewLoggerV2(io.Discard, io.Discard, io.Discard))
 
-	cli.VersionPrinter = func(c *cli.Context) {
-		fmt.Println(c.App.Name, version.Package, c.App.Version, version.Revision)
+	cli.VersionPrinter = func(cliContext *cli.Context) {
+		fmt.Println(cliContext.App.Name, version.Package, cliContext.App.Version, version.Revision)
+	}
+	cli.VersionFlag = &cli.BoolFlag{
+		Name:    "version",
+		Aliases: []string{"v"},
+		Usage:   "Print the version",
+	}
+	cli.HelpFlag = &cli.BoolFlag{
+		Name:    "help",
+		Aliases: []string{"h"},
+		Usage:   "Show help",
 	}
 }
 
@@ -77,40 +87,43 @@ at the default file location. The *containerd config* command can be used to
 generate the default configuration for containerd. The output of that command
 can be used and modified as necessary as a custom configuration.`
 	app.Flags = []cli.Flag{
-		cli.StringFlag{
-			Name:  "config,c",
-			Usage: "Path to the configuration file",
-			Value: filepath.Join(defaults.DefaultConfigDir, "config.toml"),
+		&cli.StringFlag{
+			Name:    "config",
+			Aliases: []string{"c"},
+			Usage:   "Path to the configuration file",
+			Value:   filepath.Join(defaults.DefaultConfigDir, "config.toml"),
 		},
-		cli.StringFlag{
-			Name:  "log-level,l",
-			Usage: "Set the logging level [trace, debug, info, warn, error, fatal, panic]",
+		&cli.StringFlag{
+			Name:    "log-level",
+			Aliases: []string{"l"},
+			Usage:   "Set the logging level [trace, debug, info, warn, error, fatal, panic]",
 		},
-		cli.StringFlag{
-			Name:  "address,a",
-			Usage: "Address for containerd's GRPC server",
+		&cli.StringFlag{
+			Name:    "address",
+			Aliases: []string{"a"},
+			Usage:   "Address for containerd's GRPC server",
 		},
-		cli.StringFlag{
+		&cli.StringFlag{
 			Name:  "root",
 			Usage: "containerd root directory",
 		},
-		cli.StringFlag{
+		&cli.StringFlag{
 			Name:  "state",
 			Usage: "containerd state directory",
 		},
 	}
 	app.Flags = append(app.Flags, serviceFlags()...)
-	app.Commands = []cli.Command{
+	app.Commands = []*cli.Command{
 		configCommand,
 		publishCommand,
 		ociHook,
 	}
-	app.Action = func(context *cli.Context) error {
+	app.Action = func(cliContext *cli.Context) error {
 		var (
 			start       = time.Now()
 			signals     = make(chan os.Signal, 2048)
 			serverC     = make(chan *server.Server, 1)
-			ctx, cancel = gocontext.WithCancel(gocontext.Background())
+			ctx, cancel = context.WithCancel(cliContext.Context)
 			config      = defaultConfig()
 		)
 
@@ -118,16 +131,16 @@ can be used and modified as necessary as a custom configuration.`
 
 		// Only try to load the config if it either exists, or the user explicitly
 		// told us to load this path.
-		configPath := context.GlobalString("config")
+		configPath := cliContext.String("config")
 		_, err := os.Stat(configPath)
-		if !os.IsNotExist(err) || context.GlobalIsSet("config") {
-			if err := srvconfig.LoadConfig(configPath, config); err != nil {
+		if !os.IsNotExist(err) || cliContext.IsSet("config") {
+			if err := srvconfig.LoadConfig(ctx, configPath, config); err != nil {
 				return err
 			}
 		}
 
 		// Apply flags to the config
-		if err := applyFlags(context, config); err != nil {
+		if err := applyFlags(cliContext, config); err != nil {
 			return err
 		}
 
@@ -290,7 +303,7 @@ can be used and modified as necessary as a custom configuration.`
 	return app
 }
 
-func serve(ctx gocontext.Context, l net.Listener, serveFunc func(net.Listener) error) {
+func serve(ctx context.Context, l net.Listener, serveFunc func(net.Listener) error) {
 	path := l.Addr().String()
 	log.G(ctx).WithField("address", path).Info("serving...")
 	go func() {
@@ -301,10 +314,10 @@ func serve(ctx gocontext.Context, l net.Listener, serveFunc func(net.Listener) e
 	}()
 }
 
-func applyFlags(context *cli.Context, config *srvconfig.Config) error {
+func applyFlags(cliContext *cli.Context, config *srvconfig.Config) error {
 	// the order for config vs flag values is that flags will always override
 	// the config values if they are set
-	if err := setLogLevel(context, config); err != nil {
+	if err := setLogLevel(cliContext, config); err != nil {
 		return err
 	}
 	if err := setLogFormat(config); err != nil {
@@ -328,7 +341,7 @@ func applyFlags(context *cli.Context, config *srvconfig.Config) error {
 			d:    &config.GRPC.Address,
 		},
 	} {
-		if s := context.GlobalString(v.name); s != "" {
+		if s := cliContext.String(v.name); s != "" {
 			*v.d = s
 			if v.name == "root" || v.name == "state" {
 				absPath, err := filepath.Abs(s)
@@ -340,13 +353,13 @@ func applyFlags(context *cli.Context, config *srvconfig.Config) error {
 		}
 	}
 
-	applyPlatformFlags(context)
+	applyPlatformFlags(cliContext)
 
 	return nil
 }
 
-func setLogLevel(context *cli.Context, config *srvconfig.Config) error {
-	l := context.GlobalString("log-level")
+func setLogLevel(cliContext *cli.Context, config *srvconfig.Config) error {
+	l := cliContext.String("log-level")
 	if l == "" {
 		l = config.Debug.Level
 	}
